pub struct LsmDir {
    dir: AntiCollisionParentDir,
}

Fields

dir: AntiCollisionParentDir

Implementations

source

impl LsmDir

source

pub fn load_or_new<P: AsRef<Path>>(lsm_dir_path: P) -> Result<(Self, LsmState)>

source

fn collect_committed_unit_dirs<P: AsRef<Path>>( lsm_dir_path: P ) -> Result<(BinaryHeap<CIUD>, AntiCollisionParentDir)>

Returns:

  • tup.0 = Priority queue of unit dirs that contain valid commit info.
  • tup.1 = The anti-filename-collision dir abstraction.
source

fn load_committed_units( pq: BinaryHeap<CIUD> ) -> Result<(Vec<CommittedUnit>, CommitVer)>

Returns:

  • Ordered vec of committed units, from highest to lowest commit versions.
  • The next commit ver.
source

pub fn format_new_unit_dir_path(&self) -> UnitDir